searchData={"items":[{"type":"module","title":"DeoxysII","doc":"This work is derived from: https://github.com/oasisprotocol/deoxysii\n\nCopyright (c) 2019 Oasis Labs Inc.  \n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS\nBE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN\nACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN\nCONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"DeoxysII.html"},{"type":"function","title":"DeoxysII.decrypt/4","doc":"Decrypts a ciphertext using Deoxys-II authenticated decryption.","ref":"DeoxysII.html#decrypt/4"},{"type":"function","title":"Parameters - DeoxysII.decrypt/4","doc":"- `self`: A DeoxysII struct containing the derived key.\n- `nonce`: A binary nonce (must be 15 bytes).\n- `ad`: Associated data that will be authenticated.\n- `ciphertext`: The ciphertext to decrypt (with authentication tag appended).","ref":"DeoxysII.html#decrypt/4-parameters"},{"type":"function","title":"Returns - DeoxysII.decrypt/4","doc":"The decrypted message if the authentication tag is valid, `nil` otherwise.","ref":"DeoxysII.html#decrypt/4-returns"},{"type":"function","title":"Examples - DeoxysII.decrypt/4","doc":"```elixir\niex> key = <<0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f,\n...>         0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x2b, 0x2c, 0x2d, 0x2e, 0x2f>>\niex> nonce = <<0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x2b, 0x2c, 0x2d, 0x2e>>\niex> deoxys = DeoxysII.new(key)\niex> ciphertext = <<0x2b, 0x97, 0xbd, 0x77, 0x71, 0x2f, 0x0c, 0xde, 0x97, 0x53, 0x09, 0x95, 0x9d, 0xfe, 0x1d, 0x7c>>\niex> DeoxysII.decrypt(deoxys, nonce, <<>>, ciphertext)\n<<>>\n\n# Encrypt and then decrypt a message with associated data\niex> key = <<0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f,\n...>         0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x2b, 0x2c, 0x2d, 0x2e, 0x2f>>\niex> nonce = DeoxysII.random_nonce()\niex> ad = <<0x00, 0x01, 0x02>>\niex> msg = <<0x10, 0x11, 0x12>>\niex> deoxys = DeoxysII.new(key)\niex> ct = DeoxysII.encrypt(deoxys, nonce, ad, msg)\niex> DeoxysII.decrypt(deoxys, nonce, ad, ct)\n<<0x10, 0x11, 0x12>>\n```","ref":"DeoxysII.html#decrypt/4-examples"},{"type":"function","title":"DeoxysII.encrypt/4","doc":"Encrypts a message using Deoxys-II authenticated encryption.","ref":"DeoxysII.html#encrypt/4"},{"type":"function","title":"Parameters - DeoxysII.encrypt/4","doc":"- `self`: A DeoxysII struct containing the derived key.\n- `nonce`: A binary nonce (must be 15 bytes).\n- `ad`: Associated data that will be authenticated but not encrypted.\n- `msg`: The message to encrypt.","ref":"DeoxysII.html#encrypt/4-parameters"},{"type":"function","title":"Returns - DeoxysII.encrypt/4","doc":"The encrypted message with the authentication tag appended.","ref":"DeoxysII.html#encrypt/4-returns"},{"type":"function","title":"Example - DeoxysII.encrypt/4","doc":"```elixir\n# Create a new DeoxysII instance with a 32-byte key\niex> key = Base.decode16!(\"000102030405060708090a0b0c0d0e0f101112131415161718191a1b1c1d1e1f\", case: :lower)\niex> nonce = DeoxysII.random_nonce()\niex> ad = Base.decode16!(\"000102030405060708090a0b0c0d0e0f\", case: :lower)\niex> msg = Base.decode16!(\"000102030405060708090a0b0c0d0e0f\", case: :lower)\niex> x = DeoxysII.new(key)\niex> ciphertext = DeoxysII.encrypt(x, nonce, ad, msg)\niex> byte_size(ciphertext) == byte_size(msg) + DeoxysII.tag_size()\ntrue\n```","ref":"DeoxysII.html#encrypt/4-example"},{"type":"function","title":"DeoxysII.new/1","doc":"","ref":"DeoxysII.html#new/1"},{"type":"function","title":"DeoxysII.nonce_size/0","doc":"","ref":"DeoxysII.html#nonce_size/0"},{"type":"function","title":"DeoxysII.random_nonce/0","doc":"","ref":"DeoxysII.html#random_nonce/0"},{"type":"function","title":"DeoxysII.tag_size/0","doc":"","ref":"DeoxysII.html#tag_size/0"},{"type":"module","title":"DeoxysII.ByteArray","doc":"Helper module for porting from Python. This is a stateful ByteArray using the Process dictionary.","ref":"DeoxysII.ByteArray.html"},{"type":"function","title":"DeoxysII.ByteArray.clear/0","doc":"","ref":"DeoxysII.ByteArray.html#clear/0"},{"type":"function","title":"DeoxysII.ByteArray.clone/1","doc":"","ref":"DeoxysII.ByteArray.html#clone/1"},{"type":"function","title":"DeoxysII.ByteArray.enumerate/1","doc":"","ref":"DeoxysII.ByteArray.html#enumerate/1"},{"type":"function","title":"DeoxysII.ByteArray.get/1","doc":"","ref":"DeoxysII.ByteArray.html#get/1"},{"type":"function","title":"DeoxysII.ByteArray.getb/2","doc":"","ref":"DeoxysII.ByteArray.html#getb/2"},{"type":"function","title":"DeoxysII.ByteArray.getc/2","doc":"","ref":"DeoxysII.ByteArray.html#getc/2"},{"type":"function","title":"DeoxysII.ByteArray.len/1","doc":"","ref":"DeoxysII.ByteArray.html#len/1"},{"type":"function","title":"DeoxysII.ByteArray.new/1","doc":"","ref":"DeoxysII.ByteArray.html#new/1"},{"type":"function","title":"DeoxysII.ByteArray.pop/1","doc":"","ref":"DeoxysII.ByteArray.html#pop/1"},{"type":"function","title":"DeoxysII.ByteArray.put/2","doc":"","ref":"DeoxysII.ByteArray.html#put/2"},{"type":"function","title":"DeoxysII.ByteArray.sub/3","doc":"a[start:stop]  # items start through stop-1\na[start:]      # items start through the rest of the array\na[:stop]       # items from the beginning through stop-1\na[:]           # a copy of the whole array","ref":"DeoxysII.ByteArray.html#sub/3"},{"type":"function","title":"DeoxysII.ByteArray.write/3","doc":"","ref":"DeoxysII.ByteArray.html#write/3"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}